"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const helpers_1 = require("../helpers");
class UserSettingsServiceBase {
    constructor(userSettingsFilePath, $fs, $lockfile, $logger) {
        this.$fs = $fs;
        this.$lockfile = $lockfile;
        this.$logger = $logger;
        this.userSettingsFilePath = null;
        this.userSettingsData = null;
        this.userSettingsFilePath = userSettingsFilePath;
    }
    get lockFilePath() {
        return `${this.userSettingsFilePath}.lock`;
    }
    getSettingValue(settingName) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = () => __awaiter(this, void 0, void 0, function* () {
                yield this.loadUserSettingsFile();
                return this.userSettingsData ? this.userSettingsData[settingName] : null;
            });
            return this.executeActionWithLock(action);
        });
    }
    saveSetting(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            const settingObject = {};
            settingObject[key] = value;
            return this.saveSettings(settingObject);
        });
    }
    removeSetting(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = () => __awaiter(this, void 0, void 0, function* () {
                yield this.loadUserSettingsFile();
                delete this.userSettingsData[key];
                yield this.saveSettings();
            });
            return this.executeActionWithLock(action);
        });
    }
    executeActionWithLock(action) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.$lockfile.lock(this.lockFilePath);
                const result = yield action();
                return result;
            }
            finally {
                this.$lockfile.unlock(this.lockFilePath);
            }
        });
    }
    saveSettings(data) {
        const action = () => __awaiter(this, void 0, void 0, function* () {
            yield this.loadUserSettingsFile();
            this.userSettingsData = this.userSettingsData || {};
            _(data)
                .keys()
                .each(propertyName => {
                this.userSettingsData[propertyName] = data[propertyName];
            });
            this.$fs.writeJson(this.userSettingsFilePath, this.userSettingsData);
        });
        return this.executeActionWithLock(action);
    }
    loadUserSettingsFile() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.userSettingsData) {
                yield this.loadUserSettingsData();
            }
        });
    }
    loadUserSettingsData() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.$fs.exists(this.userSettingsFilePath)) {
                const unexistingDirs = this.getUnexistingDirectories(this.userSettingsFilePath);
                this.$fs.writeFile(this.userSettingsFilePath, null);
                if (process.env.SUDO_USER) {
                    for (const dir of unexistingDirs) {
                        yield this.$fs.setCurrentUserAsOwner(dir, process.env.SUDO_USER);
                    }
                }
            }
            const data = this.$fs.readText(this.userSettingsFilePath);
            try {
                this.userSettingsData = helpers_1.parseJson(data);
            }
            catch (err) {
                this.$logger.trace(`Error while trying to parseJson ${data} data from ${this.userSettingsFilePath} file. Err is: ${err}`);
                this.$fs.deleteFile(this.userSettingsFilePath);
            }
        });
    }
    getUnexistingDirectories(filePath) {
        const unexistingDirs = [];
        let currentDir = path.join(filePath, "..");
        while (true) {
            if (this.$fs.exists(currentDir)) {
                break;
            }
            unexistingDirs.push(currentDir);
            currentDir = path.join(currentDir, "..");
        }
        return unexistingDirs;
    }
}
exports.UserSettingsServiceBase = UserSettingsServiceBase;
